# BugSwarm CFG

## To run BugSwarm CFG generation with Spoon
```bugswarm-cfg --image-tag dromara-hertzbeat-12624254643 --tool spoon```

## To run BugSwarm CFG generation with JavaParser
```bugswarm-cfg --image-tag dromara-hertzbeat-12624254643 --tool javaparser```
